@@ -469,14 +469,14 @@ class ZarrDataSource(ImageDataSource):
             x_meters_center=x_meters_center, y_meters_center=y_meters_center
         )
         selected_data = selected_data.sel(
-            x=slice(bounding_box.left, bounding_box.right),
-            y=slice(bounding_box.top, bounding_box.bottom),
+            x_osgb=slice(bounding_box.left, bounding_box.right),
+            y_osgb=slice(bounding_box.top, bounding_box.bottom),
         )
 
         # selected_sat_data is likely to have 1 too many pixels in x and y
         # because sel(x=slice(a, b)) is [a, b], not [a, b).  So trim:
         selected_data = selected_data.isel(
-            x=slice(0, self._square.size_pixels), y=slice(0, self._square.size_pixels)
+            x_osgb=slice(0, self._square.size_pixels), y_osgb=slice(0, self._square.size_pixels)
         )
 
         selected_data = self._post_process_example(selected_data, t0_dt)
