@@ -10,7 +10,7 @@ class OpticalFlow(DataSourceOutput):
     """Class to store optical flow data as a xr.Dataset with some validation"""
 
     __slots__ = ()
-    _expected_dimensions = ("time", "x", "y", "channels")
+    _expected_dimensions = ("time", "x_osgb", "y_osgb", "channels")
     _expected_data_vars = ("data",)
 
     @classmethod
